<?php
/**
 * Adds administration grid
 *
 * When this plugin is installed, `Guestbook` panel appears in administration site.
 *
 */

namespace Plugin\Guestbook;


class AdminController 
{

    public function index()
    {
        if (ipGetOption('Guestbook.separateLanguages') == 1) $this->setSubmenu();
        return $this->entriesGrid();
    }

    public function entriesGrid()
    {
           
        $fields = array();
        
        $fields[] = array(
            'type'  => 'Checkbox',
            'label' => __('Enabled', 'Guestbook'),
            'field' => 'enabled',
            );
        
        $fields[] = array(
            'label' => __('Language', 'Guestbook'),
            'field' => 'langCode',
            'allowUpdate' => false,
            'preview' => ipGetOption('Guestbook.separateLanguages') == 1 ? false : true
            );
        
        $fields[] = array(
            'label' => __('Submitted by', 'Guestbook'),
            'field' => 'personName',
            'validators' => array('Required')
        );
        
        $fields[] = array(
            'label' => __('E-mail', 'Guestbook'),
            'field' => 'email',
            'validators' => array('Email')
            );    
           
        $fields[] = array(
            'label' => __('Message', 'Guestbook'),
            'field' => 'message',
            'type' => 'Textarea',
            'validators' => array('Required')
            );
        
        $fields[] = array(
            'label' => __('Date submitted', 'Guestbook'),
            'field' => 'dateSubmitted',
            'preview' => true
            );    
        
        $fields[] = array(
            'label' => __('Comment', 'Guestbook'),
            'field' => 'comment',
            'type' => 'Textarea',
            );
              
        $config = array(  
            'title' => __('Guestbook', 'Guestbook'),
            'table' => 'guestbook',
            'deleteWarning' => __('Do you really want to delete this item?', 'Guestbook'),
            'sortField' => 'dateSubmitted',
            'sortDirection' => 'desc',
            'createPosition' => 'top',
            'fields' => $fields
        );
        
        if (ipGetOption('Guestbook.separateLanguages') == 1) {
            
            $config['filter'] = '(langCode = "'.$this->getLanguageFilter().'")';
            $config['gatewayData'] = array('lang' => $this->getLanguageFilter());
            
        }
        
        
        return ipGridController($config);

    }


    private function getLanguageFilter(){

        $queryLang =  ipRequest()->getQuery('lang');
        $postLang = ipRequest()->getPost('langCode');
                
        if (empty($queryLang) && empty($postLang)) {
            $languages = array();
            $languages = $this->getLanguages();
            return $languages[0][0];
        } else if ($postLang) {
            return $postLang;
        } else {
            return $queryLang;
        }
        
    }
    
    private function checkMenuStatus($lang, $isDefault = false){
       
        $queryLang = ipRequest()->getQuery('lang');
     
            if ($lang == $queryLang){
                   return true;
            } else if ((empty($queryLang)) && ($isDefault)){
                return true;
            } else {
                   return false;
            }
           
    }

    protected function setMenuItem($title, $method, $language, $isDefault = false){

        $menuItem = new \Ip\Menu\Item();
        $menuItem->setTitle($title); //
        $menuItem->setUrl(ipActionUrl(array('aa' => $method, 'lang' => $language)));
        $menuItem->markAsCurrent($this->checkMenuStatus($language, $isDefault));

        return $menuItem;
    }

    protected function setSubmenu()
    {
       
        $languages = array();
        $languages = $this->getLanguages();
        
        $submenu = array();
        $i = 0;
        foreach ($languages as $language) {
            
            $default = ($i === 0) ? true : false;
            $i++;
          
            $submenu[] = $this->setMenuItem($language[0], 'Guestbook', $language[0], $default);
            
        }
  
        ipResponse()->setLayoutVariable('submenu', $submenu);
    }



    private static function getLanguages(){

        $langObjects = ipContent()->getLanguages();
        $languages = Array();

        foreach ($langObjects as $langObject){
            $language = array($langObject->getCode(), $langObject->longDescription);
            $languages[] = $language;
        }

        return $languages;
    }
    
    
    
} 