<?php
namespace Plugin\Guestbook;

class SiteController extends \Ip\Controller
{

    public function getPageAjax() {
        
        ipRequest()->mustBePost();
        $params = ipRequest()->getPost('params');

        $currentPage = $params['page'];
        $pageSize = $params['pagination']['pagesize'];

    if (1==1) {
    
        $guestbookContent = $this->getGuestbookContent($pageSize,$currentPage);
                
        return new \Ip\Response\JsonRpc(ipView('Widget/Guestbook/skin/default.php', $guestbookContent)->render());
        
    } else {
        return \Ip\Response\JsonRpc::error("Page not found");
    }
}

    public static function getGuestbookContent($pageSize, $currentPage) {
        
        if (ipGetOption('Guestbook.separateLanguages') == 1) {
            $langCode = ipContent()->getCurrentLanguage()->getCode();
        } else {
            $langCode = '';
        }
        
        if ($currentPage < 1) {
            $currentPage = 1;
        }

        $from = ($currentPage - 1) * $pageSize;

        $totalPages = ceil(Model::recordCount($langCode) / $pageSize);

        if ($currentPage > $totalPages) {
            $currentPage = $totalPages;
        }
    
        $pagination = new \Ip\Pagination\Pagination(array(
            'currentPage' => $currentPage,
            'totalPages' => $totalPages,
            'pageSize' => $pageSize
        ));
        
        $variables = array(
            'entries' => Model::getAllEntries($from, $pageSize, $langCode),
            'pagination' => $pagination->render(ipFile('Plugin/Guestbook/view/pagination.php'))
        );
        
        return $variables;
    
    }

    public function showForm()
    {

        $form = FrontendForm::createForm();
        $data['form'] = $form;
        $renderedHtml = ipView('view/form.php', $data)->render();

        return $renderedHtml;
    }

    public function save()
    {

        $form = FrontendForm::createForm();

        $postData = ipRequest()->getPost();
        $errors = $form->validate($postData);
        
        if ($errors) {
            
            // Validation error
            $status = array('status' => 'error', 'errors' => $errors);

            return new \Ip\Response\Json($status);
        
        } else {
            
            // Success
            $langCode = ipContent()->getCurrentLanguage()->getCode();
            
            $entry = array(
                'langCode' => $langCode,
                'personName' => ipRequest()->getPost('personName'),
                'email' => ipRequest()->getPost('email'),
                'message' => ipRequest()->getPost('message'),
                'dateSubmitted' => date('Y-m-d H:i')
            );

            Model::saveGuestbookRecord($entry);
            
            if (ipGetOption('Guestbook.emailNotification') == 1) {
                
                $emailData = array(
                    'title' => __('New entry in Guestbook', 'Guestbook'),
                    'content' => ipView('view/mailcontent.php', $entry)->render()
                );
 
                $emailHtml = ipEmailTemplate($emailData);  
                
                ipSendEmail(
                    ipGetOptionLang('Config.websiteEmail', $langCode),
                    __('Guestbook at site ', 'Guestbook') . ipGetOptionLang('Config.websiteTitle', $langCode),
                    ipGetOptionLang('Config.websiteEmail', $langCode),
                    'Website-Administrator',
                    __('New entry in Guestbook', 'Guestbook'),
                    $emailHtml,
                    true
                );
            }

            $actionUrl = ipActionUrl(array('sa' => 'Guestbook.showSuccessMessage'));
            $status = array('redirectUrl' => $actionUrl);
            return new \Ip\Response\Json($status);
        }

    }

    public function showSuccessMessage()
    {
        $renderedHtml = ipView('view/success.php')->render();

        return $renderedHtml;
    
    }





}
